@@ -47,7 +47,7 @@ att_from_rscript <- function(path) {
 #' @param path directory with R scripts inside or vector of R scripts
 #' @param pattern pattern to detect R script files
 #' @param recursive logical. Should the listing recurse into directories?
-#'
+#' @param folder_to_exclude Folder to exclude during scan to detect packages. 'renv' by default.
 #' @return vector of character of packages names found in the R script
 #'
 #' @export
@@ -58,7 +58,7 @@ att_from_rscript <- function(path) {
 #' att_from_rscripts(path = file.path(dummypackage, "R"))
 #' att_from_rscripts(path = list.files(file.path(dummypackage, "R"), full.names = TRUE))
 
-att_from_rscripts <- function(path = "R", pattern = "*.[.](r|R)$", recursive = TRUE) {
+att_from_rscripts <- function(path = "R", pattern = "*.[.](r|R)$", recursive = TRUE, folder_to_exclude = "renv") {
 
   if (isTRUE(all(dir.exists(path)))) {
     all_f <- list.files(path, full.names = TRUE, pattern = pattern, recursive = recursive)
@@ -68,6 +68,16 @@ att_from_rscripts <- function(path = "R", pattern = "*.[.](r|R)$", recursive = T
     stop("Some files/directories do not exist")
   }
 
+  if (!is.null(folder_to_exclude) && length(folder_to_exclude) > 0) {
+    exclude_files <- unlist(lapply(folder_to_exclude, function(folder) {
+      list.files(path = file.path(path, folder), full.names = TRUE, pattern = pattern, recursive = recursive)
+    }))
+
+    # Exclure les fichiers
+    all_f <- setdiff(all_f, exclude_files)
+  }
+
+
   lapply(all_f, att_from_rscript) %>%
     unlist() %>%
     unique() %>%
