@@ -4,8 +4,12 @@
 #'
 #' @export
 #' @importFrom magrittr %>%
+#' @examples
+#' # example code
+#' library(utils)
+#' data("fruit", package = "stringr")
 my_mean <- function(x){
   x <- x %>% stats::na.omit()
   1+1
-  sum(x)/length(x)
+  sum(x)/base::length(x)
 }
